==> bageldb-nuxt-0.1.0.tgz: package/lib/bageldb-nuxt.js <==
'use-strict'

const axios = require("axios");
const cookie = require('cookie')

class BagelNuxt {
    constructor(apiToken, ctx) {
        this.ctx = ctx;
        this.apiToken = apiToken;
        this.axiosInstance = axios.create();
        this.axiosInstance.interceptors.request.use((config) => {
            config.headers["Accept-Version"] = "v1";
            if (new BagelUsersRequest({ instance: this })._bagelUserActive() && !config.url.includes("user/token")) {
                let accessToken = new BagelUsersRequest({ instance: this })._getAccessToken()
                config.headers.Authorization = "Bearer " + accessToken;
            } else {
                config.headers.Authorization = "Bearer " + apiToken;
            }
            return config;
        }, (error) => {
            return Promise.reject(error);
        });

        this.axiosInstance.interceptors.response.use(
            response => {
                return response;
            }, (error) => {
                if (new BagelUsersRequest({ instance: this })._bagelUserActive() && error.response && error.response.status == 401 && !error.config.url.includes("user/token")) {
                    return new BagelUsersRequest({ instance: this }).refresh().then(() => {
                        const config = error.config;
                        config.headers["Authorization"] = `Bearer ${new BagelUsersRequest({ instance: this })._getAccessToken()}`;
                        return new Promise((resolve, reject) => {
                            axios
                                .request(config)
                                .then(response => {
                                    resolve(response);
                                })
                                .catch(error => {
                                    reject(error);
                                });
                        });
                    }).catch(() => {
                        return Promise.reject(error);
                    })
                }
                return Promise.reject(error);
            });
    }

    schema(collectionID) {
        return new BagelMetaRequest({ instance: this, collectionID })
    }

    collection(collectionID) {
        return new BagelDBRequest({ instance: this, collectionID })
    }

    users() {
        return new BagelUsersRequest({ instance: this })
    }

    static get ASC() {
        return "ASC"
    }

    static get DESC() {
        return "DESC"
    }

    static get EQUAL() {
        return "="
    }

    static get NOT_EQUAL() {
        return "!="
    }

    static get GREATER_THAN() {
        return ">"
    }

    static get LESS_THAN() {
        return "<"
    }
}

const baseEndpoint = 'https://api.bagelstudio.co/api/public';
const liveEndpoint = 'https://live.bageldb.com/api/public';
const AUTH_ENDPOINT = "https://auth.bageldb.com/api/public"

module.exports = BagelNuxt;
module.exports.default = BagelNuxt;

class BagelMetaRequest {
    constructor({ instance, collectionID }) {
        this.instance = instance;
        this.collectionID = collectionID;
    }

    get() {
        return new Promise(async (resolve, reject) => {
            let url = `${baseEndpoint}/collection/${this.collectionID}/schema`;
            await this.instance.axiosInstance.get(url).then((res) => {
                if (res.status >= 200 && res.status < 400) {
                    resolve(res)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        });
    }
}

class BagelDBRequest {
    constructor({ instance, collectionID }) {
        this.instance = instance;
        this.collectionID = collectionID;
        this._pageNumber = 1;
        this.itemsPerPage = 100;
        this.callEverything = false;
        this._query = [];
        this.nestedCollectionsIDs = [];
        this.axiosInstance = axios.create();
        this.apiToken = instance.apiToken
        this.requestID;
        this.client;
    }

    pageNumber(pageNumber) {
        this._pageNumber = pageNumber;
        return this;
    }

    perPage(perPage) {
        this.itemsPerPage = perPage;
        return this
    }

    everything() {
        this.callEverything = true;
        return this;
    }

    collection(collectionSlug) {
        this.nestedCollectionsIDs.push(collectionSlug)
        return this
    }

    item(_id) {
        if (!_id) throw ('item cant be ' + _id);
        if (this._item) {
            if (this.nestedCollectionsIDs.length % 2 === 0) throw ("a nested item can only be placed after a nested collection")
            this.nestedCollectionsIDs.push(_id)
        } else {
            this._item = _id;
        }
        return this;
    }

    query(key, operator, value) {
        if (!key) return this;
        if (Array.isArray(value)) value = value.join(",");
        let query = key + ":" + operator + ":" + value;
        this._query.push(encodeURI(query));
        return this
    }

    sort(field, order) {
        this.sortField = field;
        this.sortOrder = order || "";
        return this
    }

    // Either of imageLink or selectedImage must be used
    // selectedImage expects a file stream i.e fs.createReadStream(filename)
    uploadImage(imageSlug, { selectedImage, imageLink, altText }) {
        var isNode = new Function("try {return this===global;}catch(e){return false;}");
        let form;
        if (isNode()) {
            const FormData = require('form-data');
            form = new FormData();
        } else {
            form = new FormData();
        }
        let nestedID = this.nestedCollectionsIDs.join(".")
        if (altText) {
            form.append("altText", altText);
        }
        if (imageLink) {
            form.append("imageLink", imageLink)
        } else {
            form.append("imageFile", selectedImage);
        }
        let formHeaders
        if (isNode()) {
            formHeaders = form.getHeaders();
        }
        return new Promise((resolve, reject) => {
            let url = `${baseEndpoint}/collection/${this.collectionID}/items/${this._item}/image?imageSlug=${imageSlug}&nestedID=${nestedID}`;
            this.instance.axiosInstance.put(url, form, { headers: formHeaders }).then(imgResponse => {
                resolve(imgResponse);
            }).catch(err =>
                reject(err))
        });

    }

    delete() {
        let nestedID = this.nestedCollectionsIDs.join(".")
        let url = `${baseEndpoint}/collection/${this.collectionID}/items/${this._item}`;
        if (nestedID) url = url + `?nestedID=${nestedID}`;
        return new Promise((resolve, reject) => {
            this.instance.axiosInstance.delete(url).then(res => resolve(res)).catch(err => reject(err))
        });
    }

    set(data) {
        let nestedID = this.nestedCollectionsIDs.join(".")
        let url = `${baseEndpoint}/collection/${this.collectionID}/items/${this._item}?set=true`;
        if (nestedID) url = url + `&nestedID=${nestedID}`;
        return new Promise((resolve, reject) => {
            this.instance.axiosInstance.put(url, JSON.stringify(data)).then(async res => {
                resolve(res);
            }).catch(err =>
                reject(err))
        });
    }

    put(data) {
        let nestedID = this.nestedCollectionsIDs.join(".")
        let url = `${baseEndpoint}/collection/${this.collectionID}/items/${this._item}`;
        if (nestedID) url = url + `?nestedID=${nestedID}`;
        return new Promise((resolve, reject) => {
            this.instance.axiosInstance.put(url, JSON.stringify(data)).then(async res => {
                resolve(res);
            }).catch(err =>
                reject(err))
        });
    }

    post(data) {
        let nestedID = this.nestedCollectionsIDs.join(".")
        return new Promise((resolve, reject) => {
            let url = `${baseEndpoint}/collection/${this.collectionID}/items`;
            if (nestedID) url = url + `/${this._item}?nestedID=${nestedID}`;
            this.instance.axiosInstance.post(url, data)
                .then(res => {
                    resolve(res);
                })
                .catch((error) => {
                    reject(error);
                });
        })
    }

    append(fieldSlug, value) {
        let nestedID = this.nestedCollectionsIDs.join(".")
        return new Promise(((resolve, reject) => {
            let url = `${baseEndpoint}/collection/${this.collectionID}/items/${this._item}/field/${fieldSlug}`;
            if (nestedID) url = url + `?nestedID=${nestedID}`;
            this.instance.axiosInstance.put(url, { value: value })
                .then(res => {
                    resolve(res);
                })
                .catch((error) => {
                    reject(error);
                });
        }))
    }

    unset(fieldSlug, value) {
        let nestedID = this.nestedCollectionsIDs.join(".")
        return new Promise(((resolve, reject) => {
            let url = `${baseEndpoint}/collection/${this.collectionID}/items/${this._item}/field/${fieldSlug}`;
            if (nestedID) url = url + `?nestedID=${nestedID}`;
            this.instance.axiosInstance.delete(url, { data: { value: value } })
                .then(res => {
                    resolve(res);
                })
                .catch((error) => {
                    reject(error);
                });
        }))
    }

    get() {
        return new Promise(async (resolve, reject) => {
            let params = new URLSearchParams();
            let nestedID = this.nestedCollectionsIDs.join(".")
            this._pageNumber ? params.append("pageNumber", this._pageNumber) : '';
            this.sortField ? params.append("sort", this.sortField) : '';
            this.sortOrder ? params.append("order", this.sortOrder) : '';
            this.itemsPerPage ? params.append("perPage", this.itemsPerPage) : '';
            this.callEverything ? params.append("everything", this.callEverything) : '';

            let itemID = this._item ? '/' + this._item : '';

            let url = `${baseEndpoint}/collection/${this.collectionID}/items${itemID}?${params.toString()}`;
            if (this._query.length > 0) url = url + "&query=" + this._query.join("%2B");
            if (nestedID) url = url + `&nestedID=${nestedID}`;

            await this.instance.axiosInstance.get(url).then((res) => {
                if (res.status >= 200 && res.status < 400) {
                    resolve(res)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        });
    }

    // Client is returned. It must be closed when it is no longer required using client.close()
    // onmessage and onerror are callback functions to process the data
    // see https://developer.mozilla.org/en-US/docs/Web/API/EventSource for more info on Server Side Events (SSE)
    listen(onmessage, onerror) {
        let url = liveEndpoint + `/collection/${this.collectionID}/live?authorization=${this.apiToken}`
        this.client = new EventSource(url)
        let that = this;
        this.client.addEventListener("start", function (e) {
            that.requestID = e.data
        })
        this.client.addEventListener("stop", function (e) {
            that.client.close()
            let url = liveEndpoint + `/collection/${that.collectionID}/live?authorization=${that.apiToken}&requestID=${that.requestID}`
            that.client = new EventSource(url)
            that.client.onmessage = onmessage
            that.client.onerror = onerror
        })
        this.client.onmessage = onmessage
        this.client.onerror = onerror
        return this.client
    }

}

class BagelUsersRequest {

    constructor({ instance }) {
        this.instance = instance
        this.ctx = instance.ctx;
    }

    _isBrowser() {
        var isNode = new Function("try {return this===global;}catch(e){return false;}");
        return !isNode()
    }

    _bagelUserActive() {
        return this.getBagelUserID() != null && this.getBagelUserID().length > 0
    }

    create(email, password) {
        return new Promise(async (resolve, reject) => {
            let url = `${AUTH_ENDPOINT}/user`;
            let body = { email: email, password: password }
            await this.instance.axiosInstance.post(url, body).then((res) => {
                if (res.status == 201) {
                    let { data } = res
                    this._storeTokens(data.access_token, data.refresh_token)
                    this._storeBagelUser(data.user_id)
                    resolve(data.user_id)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        })
    }


    validate(email, password) {
        return new Promise(async (resolve, reject) => {
            let url = `${AUTH_ENDPOINT}/user/verify`;
            let body = { email: email, password: password }
            await this.instance.axiosInstance.post(url, body).then((res) => {
                if (res.status == 200) {
                    let { data } = res
                    this._storeTokens(data.access_token, data.refresh_token)
                    this._storeBagelUser(data.user_id)
                    resolve(data.user_id)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        })
    }

    getUser() {
        return new Promise(async (resolve, reject) => {
            if (!this._bagelUserActive()) {
                reject(new Error("a Bagel User must be logged in to get Bagel User info"))
                return
            }
            let url = `${AUTH_ENDPOINT}/user`;
            await this.instance.axiosInstance.get(url).then((res) => {
                if (res.status == 200) {
                    resolve(res)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        })
    }

    updatePassword(email, updatedPassword) {
        return new Promise(async (resolve, reject) => {
            if (this._isBrowser()) {
                reject(new Error("Update Password feature is only available when using NodeJS"))
                return
            }
            let url = `${AUTH_ENDPOINT}/user/updatePassword`;
            let body = { email: email, password: updatedPassword }
            await this.instance.axiosInstance.post(url, body).then((res) => {
                if (res.status == 200) {
                    resolve(res)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        })
    }

    _getCookie(key) {
        const cookieStr = process.client
            ? document.cookie
            : this.ctx.req.headers.cookie
        const cookies = cookie.parse(cookieStr || '') || {}
        return cookies[key]
    }

    _setCookie(key, value, options) {
        if ((process.server && !this.ctx.res)) return
        const _key = key
        const _value = typeof value === 'string' ? value : JSON.stringify(value)
        const _options = options || {}
        _options.expires = new Date(Date.now() + 7 * 864e5)
        const serializedCookie = cookie.serialize(_key, _value, _options)

        if (process.client) {
            // Set in browser
            document.cookie = serializedCookie
        } else if (process.server && this.ctx.res) {
            // Send Set-Cookie header from server side
            const cookies = (this.ctx.res.getHeader('Set-Cookie')) || []
            cookies.unshift(serializedCookie)
            this.ctx.res.setHeader(
                'Set-Cookie',
                cookies.filter((v, i, arr) =>
                    arr.findIndex((val) => val.startsWith(v.substr(0, v.indexOf('=')))) === i
                )
            )
        }
        return value
    }

    _removeCookie(key) {
        this._setCookie(key, undefined, { maxAge: -1 })
    }

    _storeBagelUser(userID) {
        this._setCookie('bagel-user', userID)
    }

    _storeTokens(accessToken, refreshToken) {
        this._setCookie('bagel-access', accessToken)
        this._setCookie('bagel-refresh', refreshToken)
    }

    getBagelUserID() {
        return this._getCookie("bagel-user")
    }

    _getRefreshToken() {
        return this._getCookie("bagel-refresh")
    }

    _getAccessToken() {
        return this._getCookie("bagel-access")
    }

    logout() {
        this._removeCookie('bagel-user')
        this._removeCookie('bagel-user')
        this._removeCookie('bagel-refresh')
    }

    refresh() {
        return new Promise(async (resolve, reject) => {
            if (!this._getRefreshToken()) {
                reject(new Error("No Bagel User is logged in"))
                return
            }
            let url = `${AUTH_ENDPOINT}/user/token`;
            let body = `grant_type=refresh_token&refresh_token=${this._getRefreshToken()}&client_id=project-client`
            await this.instance.axiosInstance.post(url, body).then((res) => {
                if (res.status === 200) {
                    let { data } = res
                    this._storeTokens(data.access_token, data.refresh_token)
                    resolve(res)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        })
    }
}

==> bageldb-nuxt-0.1.2.tgz: package/lib/bageldb-nuxt.js <==
'use-strict'

const axios = require("axios");
const cookie = require('cookie')
const BagelDB = require("@bageldb/bagel-db");
const BagelUsersRequest = require("@bageldb/bagel-db/src/users")

const AUTH_ENDPOINT = "https://auth.bageldb.com/api/public"
class BagelNuxtUser extends BagelUsersRequest {
    constructor({ instance }) {
        super({ instance })
        this.ctx = this.instance.ctx
    }

    _bagelUserActive() {
        return this.getBagelUserID() != null && this.getBagelUserID().length > 0
    }

    getUser() {
        return new Promise(async (resolve, reject) => {
            if (!this._bagelUserActive()) {
                reject(new Error("a Bagel User must be logged in to get Bagel User info"))
                return
            }
            let url = `${AUTH_ENDPOINT}/user`;
            await this.instance.axiosInstance.get(url).then((res) => {
                if (res.status == 200) {
                    resolve(res)
                } else {
                    reject(res)
                }
            }).catch((err) => {
                reject(err)
            });
        })
    }

    _isBrowser() {
        var isNode = new Function("try {return this===global;}catch(e){return false;}");
        return !isNode()
    }

    _getCookie(key) {
        const cookieStr = process.client
            ? document.cookie
            : this.ctx.req.headers.cookie
        const cookies = cookie.parse(cookieStr || '') || {}
        return cookies[key]
    }

    _setCookie(key, value, options) {
        if ((process.server && !this.ctx.res)) return
        const _key = key
        const _value = typeof value === 'string' ? value : JSON.stringify(value)
        const _options = options || {}
        _options.expires = new Date(Date.now() + 7 * 864e5)
        const serializedCookie = cookie.serialize(_key, _value, _options)

        if (process.client) {
            // Set in browser
            document.cookie = serializedCookie
        } else if (process.server && this.ctx.res) {
            // Send Set-Cookie header from server side
            const cookies = (this.ctx.res.getHeader('Set-Cookie')) || []
            cookies.unshift(serializedCookie)
            this.ctx.res.setHeader(
                'Set-Cookie',
                cookies.filter((v, i, arr) =>
                    arr.findIndex((val) => val.startsWith(v.substr(0, v.indexOf('=')))) === i
                )
            )
        }
        return value
    }

    _removeCookie(key) {
        this._setCookie(key, undefined, { maxAge: -1 })
    }

    _storeBagelUser(userID) {
        this._setCookie('bagel-user', userID)
    }

    _storeTokens(accessToken, refreshToken) {
        this._setCookie('bagel-access', accessToken)
        this._setCookie('bagel-refresh', refreshToken)
    }

    getBagelUserID() {
        return this._getCookie("bagel-user")
    }

    _getRefreshToken() {
        return this._getCookie("bagel-refresh")
    }

    _getAccessToken() {
        return this._getCookie("bagel-access")
    }

    logout() {
        this._removeCookie('bagel-user')
        this._removeCookie('bagel-user')
        this._removeCookie('bagel-refresh')
    }
}


class BagelNuxt extends BagelDB {
    constructor(apiToken, ctx) {
        super(apiToken)
        this.ctx = ctx;
        this.axiosInstance = axios.create();
        this.axiosInstance.interceptors.request.use((config) => {
            config.headers["Accept-Version"] = "v1";
            if (new BagelNuxtUser({ instance: this })._bagelUserActive() && !config.url.includes("user/token")) {
                let accessToken = new BagelNuxtUser({ instance: this })._getAccessToken()
                config.headers.Authorization = "Bearer " + accessToken;
            } else {
                config.headers.Authorization = "Bearer " + apiToken;
            }
            return config;
        }, (error) => {
            return Promise.reject(error);
        });

        this.axiosInstance.interceptors.response.use(
            response => {
                return response;
            }, (error) => {
                if (new BagelNuxtUser({ instance: this })._bagelUserActive() && error.response && error.response.status == 401 && !error.config.url.includes("user/token")) {
                    return new BagelNuxtUser({ instance: this }).refresh().then(() => {
                        const config = error.config;
                        config.headers["Authorization"] = `Bearer ${new BagelNuxtUser({ instance: this })._getAccessToken()}`;
                        return new Promise((resolve, reject) => {
                            axios
                                .request(config)
                                .then(response => {
                                    resolve(response);
                                })
                                .catch(error => {
                                    reject(error);
                                });
                        });
                    }).catch(() => {
                        return Promise.reject(error);
                    })
                }
                return Promise.reject(error);
            });
    }
    users() {
        return new BagelNuxtUser({ instance: this })
    }
}

module.exports = BagelNuxt;
module.exports.default = BagelNuxt;
